package com.comandante.creeper.Items;

import com.comandante.creeper.player.EquipmentBuilder;
import com.comandante.creeper.server.Color;
import com.comandante.creeper.world.TimeTracker;
import com.google.common.collect.Sets;

import java.util.Arrays;
import java.util.List;
import java.util.Set;
import java.util.UUID;

import static com.comandante.creeper.server.Color.*;

public enum ItemType {

    UNKNOWN(0, Arrays.asList(""), "", "", "", false, 0, 0, false, Rarity.RARE, 0, Sets.<TimeTracker.TimeOfDay>newHashSet()),
    KEY(1, Arrays.asList("key", "gold key", "shiny gold key"),
            "a shiny " + YELLOW + "gold key" + RESET,
            "a shiny " + YELLOW + "gold key" + RESET + " catches your eye.",
            "A basic key with nothing really remarkable other than its made of gold.",
            false,
            0,
            60,
            false,
            Rarity.BASIC,
            10, Sets.<TimeTracker.TimeOfDay>newHashSet(TimeTracker.TimeOfDay.NIGHT)),

    BEER(2, Arrays.asList("beer", "can of beer", "b"),
            "a dented can of " + CYAN + "beer" + RESET,
            "a " + CYAN + "beer" + RESET + " lies on the ground, unopened",
            "an ice cold " + CYAN + "beer" + RESET + " that restores 50 health" + RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            1, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BOOK(3, Arrays.asList("book", "used book"),
            MAGENTA + "a leather book" + RESET,
            MAGENTA + "a well used book" + RESET + " with what looks like a leather back rests here.",
            "A book written in a foreign language. Doesn't matter as you can't read.",
            false,
            0,
            60,
            false,
            Rarity.BASIC,
            1, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BROAD_SWORD(4, Arrays.asList("sword", "broad", "a broad sword", "the broad sword"),
            Color.CYAN + "the broad sword" + Color.RESET,
            "an iron broad sword rests upon the ground.",
            "an iron broad sword",
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            100, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    IRON_BOOTS(5, Arrays.asList("boots", "boot", "iron boots"),
            Color.CYAN + "iron boots" + Color.RESET,
            "a pair of iron boots are here on the ground.",
            "a pair of iron boots",
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            50, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    IRON_CHEST_PLATE(6, Arrays.asList("chest", "iron chest plate", "plate"),
            "iron chest plate",
            "an iron ches tplate is on the ground.",
            "an iron chest plate",
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            70, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    IRON_LEGGINGS(7, Arrays.asList("leggings", "iron leggings"),
            "iron leggings",
            "an a pair of iron leggings are here on the ground.",
            "an iron pair of leggings",
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PHANTOM_SWORD(8, Arrays.asList("phantom", "phantom sword", "the phantom sword"),
            Color.YELLOW + "the " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            "a " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " sword" + Color.RESET + " is on the ground.",
            "a " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            500, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    IRON_BRACERS(9, Arrays.asList("bracers", "iron bracers"),
            "iron bracers",
            "an a pair of iron bracers are here on the ground.",
            "an iron pair of bracers",
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            40, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PHANTOM_HELMET(10, Arrays.asList("helmet", "phantom helmet", "the phantom helmet"),
            Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            "a " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET + " is on the ground.",
            "a " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            250, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PHANTOM_CHESTPLATE(11, Arrays.asList("chestplate", "chest", "phantom chest plate", "the phantom chest plate"),
            Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " chest plate" + Color.RESET,
            "a " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " chest plate" + Color.RESET + " is on the ground.",
            "a " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " chest plate" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            350, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PHANTOM_BOOTS(12, Arrays.asList("boots", "phantom boots", "the phantom boots"),
            Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            "a pair of " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " boots" + Color.RESET + " are on the ground.",
            "a pair of " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            280, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PHANTOM_BRACERS(13, Arrays.asList("boots", "phantom bracers", "the phantom bracers"),
            Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            "a pair of " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET + " are on the ground.",
            "a pair of " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            250, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PHANTOM_LEGGINGS(14, Arrays.asList("leggings", "phantom leggings", "the phantom leggings"),
            Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            "a pair of " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET + " are on the ground.",
            "a pair of " + Color.CYAN + "phantom" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            290, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    IRON_HELMET(15, Arrays.asList("helmet", "iron helmet"),
            "iron helmet",
            "an iron helmet is on the ground.",
            "an iron helmet",
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    MITHRIL_SWORD(16, Arrays.asList("sword", "mithril sword", "mithril sword"),
            Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            "a " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " sword" + Color.RESET + " is on the ground.",
            "a " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            500, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    MITHRIL_CHESTPLATE(17, Arrays.asList("chestplate", "a mithril chestplate", "mithril chestplate"),
            Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            "a " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET + " is on the ground.",
            "a " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            400, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    MITHRIL_HELMET(18, Arrays.asList("helmet", "a mithril helmet", "mithril helmet"),
            Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            "a " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET + " is on the ground.",
            "a " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            280, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    MITHRIL_BRACERS(19, Arrays.asList("helmet", "mithril bracers", "mithril bracers"),
            Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            "a pair of " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET + " are on the ground.",
            "a pair of " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            300, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    MITHRIL_LEGGINGS(20, Arrays.asList("helmet", "mithril leggings", "mithril leggings"),
            Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            "a pair of " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET + " are on the ground.",
            "a pair of " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            350, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    MITHRIL_BOOTS(21, Arrays.asList("helmet", "mithril boots"),
            Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            "a pair of " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " boots" + Color.RESET + " are on the ground.",
            "a pair of " + Color.MAGENTA + "mithril" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            190, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PYAMITE_SWORD(22, Arrays.asList("sword", "pyamite sword", "pyamite sword"),
            Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            "a " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " sword" + Color.RESET + " is on the ground.",
            "a " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            3000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PYAMITE_CHESTPLATE(23, Arrays.asList("chestplate", "a pyamite chestplate", "pyamite chestplate"),
            Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            "a " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET + " is on the ground.",
            "a " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            2700, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PYAMITE_HELMET(24, Arrays.asList("helmet", "a pyamite helmet", "pyamite helmet"),
            Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            "a " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET + " is on the ground.",
            "a " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            2000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PYAMITE_BRACERS(25, Arrays.asList("bracers", "pyamite bracers", "pyamite bracers"),
            Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            "a pair of " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET + " are on the ground.",
            "a pair of " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            2100, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PYAMITE_LEGGINGS(26, Arrays.asList("leggings", "pyamite leggings", "pyamite leggings"),
            Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            "a pair of " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET + " are on the ground.",
            "a pair of " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            2900, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PYAMITE_BOOTS(27, Arrays.asList("helmet", "pyamite boots"),
            Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            "a pair of " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " boots" + Color.RESET + " are on the ground.",
            "a pair of " + Color.GREEN + "pyamite" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            2000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    MARIJUANA(28, Arrays.asList("marijuana", "weed", "m", "w", "f", "flowers"),
            Color.GREEN + "marijuana" + Color.RESET + " flowers" + Color.RESET,
            "some " + Color.GREEN + "marijuana" + Color.RESET + " flowers" + Color.RESET + " are here on the ground.",
            "some " + Color.GREEN + "marijuana" + Color.RESET + " flowers" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    TAPPERHET_SWORD(29, Arrays.asList("sword", "tapperhet sword"),
            Color.BOLD_ON + Color.GREEN + "tapperhet" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            "a " + Color.BOLD_ON + Color.GREEN + "tapperhet" + Color.RESET + Color.YELLOW + " sword" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "tapperhet" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            7000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VULCERIUM_SWORD(30, Arrays.asList("sword", "vulcerium sword", "vulcerium sword"),
            Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            "a " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " sword" + Color.RESET + " is on the ground.",
            "a " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            10000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VULCERIUM_CHESTPLATE(31, Arrays.asList("chestplate", "a vulcerium chestplate", "vulcerium chestplate"),
            Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            "a " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET + " is on the ground.",
            "a " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            9000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VULCERIUM_HELMET(32, Arrays.asList("helmet", "a vulcerium helmet", "vulcerium helmet"),
            Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            "a " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET + " is on the ground.",
            "a " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            6000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VULCERIUM_BRACERS(33, Arrays.asList("bracers", "vulcerium bracers", "vulcerium bracers"),
            Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            "a pair of " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET + " are on the ground.",
            "a pair of " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            5900, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VULCERIUM_LEGGINGS(34, Arrays.asList("leggings", "vulcerium leggings", "vulcerium leggings"),
            Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            "a pair of " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET + " are on the ground.",
            "a pair of " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            7500, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VULCERIUM_BOOTS(35, Arrays.asList("boots", "vulcerium boots"),
            Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            "a pair of " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " boots" + Color.RESET + " are on the ground.",
            "a pair of " + Color.RED + "vulcerium" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            7100, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    DWARF_BOOTS_OF_AGILITY(36, Arrays.asList("dwarf boots", "boots"),
            Color.BLUE + "dwarf" + Color.RESET + Color.RED + " boots" + Color.RESET,
            "a pair of " + Color.BLUE + "dwarf" + Color.RESET + Color.RED + " boots" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BLUE + "dwarf" + Color.RESET + Color.RED + " boots" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.UNCOMMON,
            2500, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    DEATHCRAWLER_SCALES(37, Arrays.asList("deathcrawler scales", "scales"),
            Color.BOLD_ON + Color.MAGENTA + "deathcrawler" + Color.RESET + Color.RED + " scales" + Color.RESET,
            "some " + Color.BOLD_ON + Color.MAGENTA + "deathcrawler" + Color.RESET + Color.RED + " scales" + Color.RESET + " are on the ground.",
            "some " + Color.BOLD_ON + Color.MAGENTA + "deathcrawler" + Color.RESET + Color.RED + " scales" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.BASIC,
            700, Sets.<TimeTracker.TimeOfDay>newHashSet()),


    DWARVEN_PENDANT(38, Arrays.asList("dwarven pendant", "pendant"),
            Color.BOLD_ON + Color.MAGENTA + "dwarven" + Color.RESET + Color.RED + " pendant" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "dwarven" + Color.RESET + Color.RED + " pendant" + Color.RESET + " are on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "dwarven" + Color.RESET + Color.RED + " pendant" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.BASIC,
            450, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BYSEN_BALLS(39, Arrays.asList("bysen balls", "balls"),
            Color.BOLD_ON + Color.MAGENTA + "bysen" + Color.RESET + Color.RED + " balls" + Color.RESET,
            "some " + Color.BOLD_ON + Color.MAGENTA + "bysen" + Color.RESET + Color.RED + " balls" + Color.RESET + " are on the ground.",
            "some " + Color.BOLD_ON + Color.MAGENTA + "bysen" + Color.RESET + Color.RED + " balls" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.BASIC,
            2000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PLASMA_TV(40, Arrays.asList("plasma tv", "plasma"),
            Color.BOLD_ON + Color.MAGENTA + "plasma" + Color.RESET + Color.RED + " tv" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "plasma" + Color.RESET + Color.RED + " tv" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "plasma" + Color.RESET + Color.RED + " tv" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.BASIC,
            6000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    DOGDICKS(41, Arrays.asList("dog", "dick", "dog dick"),
            Color.GREEN + "dog" + Color.RESET + " dick" + Color.RESET,
            "a " + Color.GREEN + "dog" + Color.RESET + " dick" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "dog" + Color.RESET + " dick" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            2500, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    PURPLE_DRANK(42, Arrays.asList("drank", "purple drank", "p", "purple", "lean", "sizzurp"),
            "a double cup of " + MAGENTA + "purple" + RESET + " drank",
            "a double cup of " + MAGENTA + "purple" + RESET + " drank rests on the ground.",
            "a tonic called " + MAGENTA + "purple" + RESET + " drank that restores 500 health" + RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            8, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    LEATHER_SATCHEL(43, Arrays.asList("leather satchel", "satchel"),
            "a " + Color.GREEN + "leather satchel" + Color.RESET,
            "a " + Color.GREEN + "leather satchel" + Color.RESET,
            "a " + Color.GREEN + "leather satchel" + Color.RESET + " with room to store 10 items.",
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            800, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BIGGERS_SKIN_SATCHEL(44, Arrays.asList("biggers skin satchel", "skin satchel"),
            "a " + Color.GREEN + "biggers skin satchel" + Color.RESET,
            "a " + Color.GREEN + "biggers skin satchel" + Color.RESET,
            "a " + Color.GREEN + "biggers skin satchel" + Color.RESET + " with room to store 100 items.",
            false,
            0,
            60,
            true,
            Rarity.BASIC,
            3000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    STRENGTH_ELIXIR(45, Arrays.asList("strength", "strength elixir", "elixir", "s", "e"),
            "an elixir of " + RED + "strength" + RESET,
            "an elixir of " + RED + "strength" + RESET + " is in an crystal vessel on the ground.",
            "an elixir of " + RED + "strength" + RESET + " that increases your might.",
            true,
            0,
            60,
            true,
            Rarity.BASIC,
            300, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    CHRONIC_JOOSE(46, Arrays.asList("chronic", "chronic joose", "joose", "c", "j"),
            "an elixir of " + GREEN + "chronic" + RESET + " joose",
            "an elixir of " + GREEN + "chronic" + RESET + " joose is in an crystal vessel on the ground.",
            "an elixir of " + GREEN + "chronic" + RESET + " joose that increases your chronic-ness.",
            true,
            0,
            60,
            true,
            Rarity.BASIC,
            1000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BISMUTH_SWORD(47, Arrays.asList("sword", "bismuth sword", "bismuth sword"),
            Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " sword" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            1000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BISMUTH_CHESTPLATE(48, Arrays.asList("chestplate", "a bismuth chestplate", "bismuth chestplate"),
            Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            800000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BISMUTH_HELMET(49, Arrays.asList("helmet", "a bismuth helmet", "bismuth helmet"),
            Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            700000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BISMUTH_BRACERS(50, Arrays.asList("bracers", "bismuth bracers", "bismuth bracers"),
            Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            650000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BISMUTH_LEGGINGS(51, Arrays.asList("leggings", "bismuth leggings", "bismuth leggings"),
            Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            900000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BISMUTH_BOOTS(52, Arrays.asList("boots", "bismuth boots"),
            Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " boots" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.MAGENTA + "bismuth" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.RARE,
            800000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    GUCCI_PANTS(53, Arrays.asList("pants", "gucci pants", "gucci pants"),
            Color.BOLD_ON + Color.CYAN + "gucci" + Color.RESET + Color.YELLOW + " pants" + Color.RESET,
            "a " + Color.BOLD_ON + Color.CYAN + "gucci" + Color.RESET + Color.YELLOW + " pants" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.CYAN + "gucci" + Color.RESET + Color.YELLOW + " pants" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.EXOTIC,
            40000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    HAZE(54, Arrays.asList("haze", "lemon", "h", "l"),
            Color.BOLD_ON + Color.YELLOW + "lemon" + Color.RESET + Color.GREEN + " haze" + Color.RESET,
            "some " + Color.BOLD_ON + Color.YELLOW + "lemon" + Color.RESET + Color.GREEN + " haze" + Color.RESET + " flowers" + Color.RESET + " are here on the ground.",
            "some " + Color.BOLD_ON + Color.YELLOW + "lemon" + Color.RESET + Color.GREEN + " haze" + Color.RESET + " flowers" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.RARE,
            5000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    YETI_CLAW(55, Arrays.asList("yeti claw", "yeti"),
            Color.BOLD_ON + "yeti" + Color.RESET + Color.RED + " claw" + Color.RESET,
            "a " + Color.BOLD_ON + "yeti" + Color.RESET + Color.RED + " claw" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + "yeti" + Color.RESET + Color.RED + " claw" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1100000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    CRYSTAL_DAGGER(56, Arrays.asList("crystal dagger", "dagger"),
            Color.BOLD_ON + Color.CYAN + "crystal" + Color.RESET + Color.RED + " dagger" + Color.RESET,
            "a " + Color.BOLD_ON + Color.CYAN + "crystal" + Color.RESET + Color.RED + " dagger" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.CYAN + "crystal" + Color.RESET + Color.RED + " dagger" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1400000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    GOLDEN_WAND(57, Arrays.asList("golden wand", "golden"),
            Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.RED + " wand" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.RED + " wand" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.RED + " wand" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1200000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    GLOWING_ORB(58, Arrays.asList("glowing orb", "orb"),
            Color.BOLD_ON + "glowing" + Color.RESET + Color.CYAN + " orb" + Color.RESET,
            "a " + Color.BOLD_ON + "glowing" + Color.RESET + Color.CYAN + " orb" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + "glowing" + Color.RESET + Color.CYAN + " orb" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    WOODEN_CHEST(59, Arrays.asList("wooden chest", "chest"),
            Color.BOLD_ON + "wooden" + Color.RESET + Color.RED + " chest" + Color.RESET,
            "a " + Color.BOLD_ON + "wooden" + Color.RESET + Color.RED + " chest" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + "wooden" + Color.RESET + Color.RED + " chest" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1100000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    ENCHANTED_SHIELD(60, Arrays.asList("enchanted shield", "enchanted"),
            Color.BOLD_ON + Color.CYAN + "enchanted" + Color.RESET + Color.CYAN + " shield" + Color.RESET,
            "a " + Color.BOLD_ON + Color.CYAN + "enchanted" + Color.RESET + Color.CYAN + " shield" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.CYAN + "enchanted" + Color.RESET + Color.CYAN + " shield" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.EXOTIC,
            50000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    AMETHYST_VIAL(61, Arrays.asList("amethyst vial", "vial"),
            Color.BOLD_ON + Color.MAGENTA + "amethyst" + Color.RESET + Color.CYAN + " vial" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "amethyst" + Color.RESET + Color.CYAN + " vial" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "amethyst" + Color.RESET + Color.CYAN + " vial" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1500000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    AMETHYST_RING(62, Arrays.asList("amethyst ring", "ring"),
            Color.BOLD_ON + Color.MAGENTA + "amethyst" + Color.RESET + Color.CYAN + " ring" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "amethyst" + Color.RESET + Color.CYAN + " ring" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "amethyst" + Color.RESET + Color.CYAN + " ring" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1800000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VULCERIUM_CHAIN(63, Arrays.asList("vulcerium chain", "chain"),
            Color.RED + "vulcerium" + Color.RESET + Color.CYAN + " chain" + Color.RESET,
            "a " + Color.RED + "vulcerium" + Color.RESET + Color.CYAN + " chain" + Color.RESET + " is on the ground.",
            "a " + Color.RED + "vulcerium" + Color.RESET + Color.CYAN + " chain" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            3000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    LION_TAIL(64, Arrays.asList("lion tail", "tail"),
            Color.BOLD_ON + "lion" + Color.RESET + Color.RED + " tail" + Color.RESET,
            "a " + Color.BOLD_ON + "lion" + Color.RESET + Color.RED + " tail" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + "lion" + Color.RESET + Color.RED + " tail" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            2200000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    SOLAR_PENDANT(65, Arrays.asList("solar pendant", "pendant"),
            Color.BOLD_ON + Color.YELLOW + "solar" + Color.RESET + " pendant" + Color.RESET,
            "a " + Color.BOLD_ON + "solar" + Color.RESET + " pendant" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + "solar" + Color.RESET + " pendant" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1700000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    SILVER_STAR(66, Arrays.asList("silver star", "star"),
            Color.BOLD_ON + "silver" + Color.RESET + Color.CYAN + " star" + Color.RESET,
            "a " + Color.BOLD_ON + "silver" + Color.RESET + Color.CYAN + " star" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + "silver" + Color.RESET + Color.CYAN + " star" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            1500000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    GOLDEN_AXE(67, Arrays.asList("golden axe", "axe"),
            Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " axe" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " axe" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " axe" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            5000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    GOLDEN_PRISM(68, Arrays.asList("golden prism", "prism"),
            Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " prism" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " prism" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " prism" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.EXOTIC,
            100000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    OBSIDIAN_BLADE(69, Arrays.asList("obsidian blade", "blade"),
            Color.BOLD_ON + Color.BLUE + "obsidian" + Color.RESET + Color.CYAN + " blade" + Color.RESET,
            "a " + Color.BOLD_ON + Color.BLUE + "obsidian" + Color.RESET + Color.CYAN + " blade" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.BLUE + "obsidian" + Color.RESET + Color.CYAN + " blade" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            4000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BOOK_OF_THORBRAND(70, Arrays.asList("Book of Thorbrand", "book", "Book"),
            Color.BOLD_ON + Color.YELLOW + "Book" + Color.RESET + " of" + Color.CYAN + " Thorbrand" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "Book" + Color.RESET + " of" + Color.CYAN + " Thorbrand" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "Book" + Color.RESET + " of" + Color.CYAN + " Thorbrand" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            5000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    GOLDEN_HARP(71, Arrays.asList("golden harp", "harp"),
            Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " harp" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " harp" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " harp" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            5000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    SILK_SCROLL(72, Arrays.asList("silk scroll", "scroll"),
            Color.BOLD_ON + Color.WHITE + "silk" + Color.RESET + Color.CYAN + " scroll" + Color.RESET,
            "a " + Color.BOLD_ON + Color.WHITE + "silk" + Color.RESET + Color.CYAN + " scroll" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.WHITE + "silk" + Color.RESET + Color.CYAN + " scroll" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            5300000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BLACK_TRUFFLE(73, Arrays.asList("black truffle", "truffle"),
            Color.BOLD_ON + Color.BLUE + "black" + Color.RESET + Color.WHITE + Color.BOLD_ON + " truffle" + Color.RESET,
            "a " + Color.BOLD_ON + Color.BLUE + "black" + Color.RESET + Color.WHITE + Color.BOLD_ON + " truffle" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.BLUE + "black" + Color.RESET + Color.WHITE + Color.BOLD_ON + " truffle" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            6000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    EMERALD_STATUE(74, Arrays.asList("emerald statue", "statue"),
            Color.BOLD_ON + Color.GREEN + "emerald" + Color.RESET + Color.CYAN + " statue" + Color.RESET,
            "a " + Color.BOLD_ON + Color.GREEN + "emerald" + Color.RESET + Color.CYAN + " statue" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "emerald" + Color.RESET + Color.CYAN + " statue" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            7000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    DEMONIC_TALISMAN(75, Arrays.asList("demonic talisman", "talisman"),
            Color.BOLD_ON + Color.RED + "demonic" + Color.RESET + Color.CYAN + " talisman" + Color.RESET,
            "a " + Color.BOLD_ON + Color.RED + "demonic" + Color.RESET + Color.CYAN + " talisman" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.RED + "demonic" + Color.RESET + Color.CYAN + " talisman" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    EYE_OF_NJAL(76, Arrays.asList("Eye of Njal", "Eye", "eye"),
            Color.BOLD_ON + Color.WHITE + "Eye" + Color.RESET + " of" + Color.RED + " Njal" + Color.RESET,
            "a " + Color.BOLD_ON + Color.WHITE + "Eye" + Color.RESET + " of" + Color.RED + " Njal" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.WHITE + "Eye" + Color.RESET + " of" + Color.RED + " Njal" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VALGARD_STONE(77, Arrays.asList("Valgard stone", "stone"),
            Color.BOLD_ON + Color.YELLOW + "Valgard" + Color.RESET + Color.CYAN + " stone" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "Valgard" + Color.RESET + Color.CYAN + " stone" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "Valgard" + Color.RESET + Color.CYAN + " stone" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8300000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BLOODSTONE(78, Arrays.asList("bloodstone", "stone"),
            Color.BOLD_ON + Color.RED + "bloodstone" + Color.RESET,
            "a " + Color.BOLD_ON + Color.RED + "bloodstone" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.RED + "bloodstone" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8500000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    HORN_OF_KOLSKEGG(79, Arrays.asList("Horn of Kolskegg", "Horn", "horn"),
            Color.BOLD_ON + Color.YELLOW + "Horn" + Color.RESET + " of" + Color.CYAN + " Kolskegg" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "Horn" + Color.RESET + " of" + Color.CYAN + " Kolskegg" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "Horn" + Color.RESET + " of" + Color.CYAN + " Kolskegg" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            12000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    ANCIENT_RUNESTONE(80, Arrays.asList("ancient runestone", "runestone"),
            Color.BOLD_ON + Color.YELLOW + "ancient" + Color.RESET + Color.WHITE + Color.BOLD_ON + " runestone" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "ancient" + Color.RESET + Color.WHITE + Color.BOLD_ON + " runestone" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "ancient" + Color.RESET + Color.WHITE + Color.BOLD_ON + " runestone" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            15000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    AEGIRS_PIPE(81, Arrays.asList("Aegirs pipe", "pipe"),
            Color.BOLD_ON + Color.YELLOW + "Aegirs" + Color.RESET + Color.CYAN + " pipe" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "Aegirs" + Color.RESET + Color.CYAN + " pipe" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "Aegirs" + Color.RESET + Color.CYAN + " pipe" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            15000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    SERPENT_IDOL(82, Arrays.asList("serpent idol", "idol"),
            Color.BOLD_ON + Color.MAGENTA + "serpent" + Color.RESET + Color.CYAN + " idol" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "serpent" + Color.RESET + Color.CYAN + " idol" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "serpent" + Color.RESET + Color.CYAN + " idol" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            20000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    SORCERORS_MONOCLE(83, Arrays.asList("Sorcerors monocle", "monocle"),
            Color.BOLD_ON + Color.RED + "Sorcerors" + Color.RESET + Color.WHITE + " monocle" + Color.RESET,
            "a " + Color.BOLD_ON + Color.RED + "Sorcerors" + Color.RESET + Color.WHITE + " monocle" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.RED + "Sorcerors" + Color.RESET + Color.WHITE + " monocle" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            20000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    SPIDER_FANG(84, Arrays.asList("spider fang", "fang"),
            Color.BOLD_ON + Color.YELLOW + "spider" + Color.RESET + Color.RED + " fang" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "spider" + Color.RESET + Color.RED + " fang" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "spider" + Color.RESET + Color.RED + " fang" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            25000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    SPIDERSILK_POUCH(85, Arrays.asList("spidersilk pouch", "pouch"),
            Color.BOLD_ON + Color.YELLOW + "spidersilk" + Color.RESET + Color.CYAN + " pouch" + Color.RESET,
            "a " + Color.BOLD_ON + Color.YELLOW + "spidersilk" + Color.RESET + Color.CYAN + " pouch" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.YELLOW + "spidersilk" + Color.RESET + Color.CYAN + " pouch" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            30000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    CRYSTAL_SPIDER(86, Arrays.asList("crystal spider", "spider"),
            Color.BOLD_ON + Color.CYAN + "crystal" + Color.RESET + Color.RED + " spider" + Color.RESET,
            "a " + Color.BOLD_ON + Color.CYAN + "crystal" + Color.RESET + Color.RED + " spider" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.CYAN + "crystal" + Color.RESET + Color.RED + " spider" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            32000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
    
    AEXIUM_SWORD(87, Arrays.asList("sword", "aexium sword", "aexium sword"),
            Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            "a " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " sword" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " sword" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            2000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    AEXIUM_CHESTPLATE(88, Arrays.asList("chestplate", "a aexium chestplate", "aexium chestplate"),
            Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            "a " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " chestplate" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            1800000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    AEXIUM_HELMET(89, Arrays.asList("helmet", "a aexium helmet", "aexium helmet"),
            Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            "a " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " helmet" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            1700000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    AEXIUM_BRACERS(90, Arrays.asList("bracers", "aexium bracers", "aexium bracers"),
            Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " bracers" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            1650000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    AEXIUM_LEGGINGS(91, Arrays.asList("leggings", "aexium leggings", "aexium leggings"),
            Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " leggings" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            1900000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    AEXIUM_BOOTS(92, Arrays.asList("boots", "aexium boots"),
            Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " boots" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.CYAN + "aexium" + Color.RESET + Color.YELLOW + " boots" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.RARE,
            1800000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    AEXIRIAN_ROOT(93, Arrays.asList("aexirian", "root", "a", "r", "aexirian root"),
            Color.GREEN + "aexirian" + Color.RESET + " root" + Color.RESET,
            "an " + Color.GREEN + "aexirian" + Color.RESET + " root" + Color.RESET + " is here on the ground.",
            "an " + Color.GREEN + "aexirian" + Color.RESET + " root" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    MITHAEM_LEAF(94, Arrays.asList("mithaem", "leaf", "m", "l", "mithaem leaf"),
            Color.GREEN + "mithaem" + Color.RESET + " leaf" + Color.RESET,
            "a " + Color.GREEN + "mithaem" + Color.RESET + " leaf" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "mithaem" + Color.RESET + " leaf" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    DURICCA_ROOT(95, Arrays.asList("duricca", "root", "d", "r", "duricca root"),
            Color.GREEN + "duricca" + Color.RESET + " root" + Color.RESET,
            "a " + Color.GREEN + "duricca" + Color.RESET + " root" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "duricca" + Color.RESET + " root" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),
    
    PONDESEL_BERRY(96, Arrays.asList("pondesel", "berry", "p", "b", "pondesel berry"),
            Color.GREEN + "pondesel" + Color.RESET + " berry" + Color.RESET,
            "a " + Color.GREEN + "pondesel" + Color.RESET + " berry" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "pondesel" + Color.RESET + " berry" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),      

    VIKALIONUS_CAP(97, Arrays.asList("vikalionus", "cap", "v", "c", "vikalionus cap"),
            Color.GREEN + "vikalionus" + Color.RESET + " cap" + Color.RESET,
            "a " + Color.GREEN + "vikalionus" + Color.RESET + " cap" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "vikalionus" + Color.RESET + " cap" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    LOORNS_LACE(98, Arrays.asList("loorn's", "lace", "l", "loorn's lace"),
            Color.GREEN + "loorn's" + Color.RESET + " lace" + Color.RESET,
            "some " + Color.GREEN + "loorn's" + Color.RESET + " lace" + Color.RESET + " is here on the ground.",
            "some " + Color.GREEN + "loorn's" + Color.RESET + " lace" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    TOURNEARES_LEAF(99, Arrays.asList("tourneares", "leaf", "t", "l", "tourneares leaf"),
            Color.GREEN + "tourneares" + Color.RESET + " leaf" + Color.RESET,
            "a " + Color.GREEN + "tourneares" + Color.RESET + " leaf" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "tourneares" + Color.RESET + " leaf" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    HAUSSIAN_BERRY(100, Arrays.asList("haussian", "berry", "h", "b", "haussian berry"),
            Color.GREEN + "haussian" + Color.RESET + " berry" + Color.RESET,
            "a " + Color.GREEN + "haussian" + Color.RESET + " berry" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "haussian" + Color.RESET + " berry" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    PERTILLIUM_ROOT(101, Arrays.asList("pertillium", "root", "p", "r", "pertillium root"),
            Color.GREEN + "pertillium" + Color.RESET + " root" + Color.RESET,
            "some " + Color.GREEN + "pertillium" + Color.RESET + " root" + Color.RESET + " is here on the ground.",
            "some " + Color.GREEN + "pertillium" + Color.RESET + " root" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    HYCIANTHIS_BARK(102, Arrays.asList("hycianthis", "bark", "h", "b", "hycianthis bark"),
            Color.GREEN + "hycianthis" + Color.RESET + " bark" + Color.RESET,
            "some " + Color.GREEN + "hycianthis" + Color.RESET + " bark" + Color.RESET + " is here on the ground.",
            "some " + Color.GREEN + "hycianthis" + Color.RESET + " bark" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    PUNILARE_FERN(103, Arrays.asList("punilare", "fern", "p", "f", "punilare fern"),
            Color.GREEN + "punilare" + Color.RESET + " fern" + Color.RESET,
            "a " + Color.GREEN + "punilare" + Color.RESET + " fern" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "punilare" + Color.RESET + " fern" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    KEAKIAR_CAP(104, Arrays.asList("keakiar", "cap", "k", "c", "keakiar cap"),
            Color.GREEN + "keakiar" + Color.RESET + " cap" + Color.RESET,
            "a " + Color.GREEN + "keakiar" + Color.RESET + " cap" + Color.RESET + " is here on the ground.",
            "a " + Color.GREEN + "keakiar" + Color.RESET + " cap" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.BASIC,
            80, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    DIRTY_BOMB(105, Arrays.asList("dirty bomb", "bomb"),
            Color.YELLOW + "dirty" + Color.RESET + " bomb" + Color.RESET,
            "a " + Color.YELLOW + "dirty" + Color.RESET + " bomb" + Color.RESET + " is here on the ground.",
            "a " + Color.YELLOW + "dirty" + Color.RESET + " bomb" + Color.RESET,
            true,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            4000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    JADE_FLASK(106, Arrays.asList("jade flask", "jade", "flask", "j", "f"),
            Color.BOLD_ON + Color.GREEN + "jade" + Color.RESET + Color.WHITE + " flask" + Color.RESET,
            "a " + Color.BOLD_ON + Color.GREEN + "jade" + Color.RESET + Color.WHITE + " flask" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "jade" + Color.RESET + Color.WHITE + " flask" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    HYCIANTHIS_FLUTE(107, Arrays.asList("hycianthis flute", "flute", "h", "f", "hycianthis"),
            Color.BOLD_ON + Color.GREEN + "hycianthis" + Color.RESET + Color.RED + " flute" + Color.RESET,
            "a " + Color.BOLD_ON + Color.GREEN + "hycianthis" + Color.RESET + Color.RED + " flute" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "hycianthis" + Color.RESET + Color.RED + " flute" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    CURSED_MIRROR(108, Arrays.asList("cursed", "mirror", "m", "c", "cursed mirror"),
            Color.BOLD_ON + Color.RED + "cursed" + Color.RESET + Color.CYAN + " mirror" + Color.RESET,
            "a " + Color.BOLD_ON + Color.RED + "cursed" + Color.RESET + Color.CYAN + " mirror" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.RED + "cursed" + Color.RESET + Color.CYAN + " mirror" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    IVORY_DART(109, Arrays.asList("ivory dart", "dart", "i", "d", "ivory"),
            Color.BOLD_ON + Color.WHITE + "ivory" + Color.RESET + Color.MAGENTA + " dart" + Color.RESET,
            "a " + Color.BOLD_ON + Color.WHITE + "ivory" + Color.RESET + Color.MAGENTA + " dart" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.WHITE + "ivory" + Color.RESET + Color.MAGENTA + " dart" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    VULCERIUM_ICEAXE(110, Arrays.asList("vulcerium ice axe", "ice axe", "axe", "v", "ice", "a"),
            Color.BOLD_ON + Color.RED + "vulcerium" + Color.RESET + Color.CYAN + " ice " + Color.RESET + "axe",
            "a " + Color.BOLD_ON + Color.RED + "vulcerium" + Color.RESET + Color.CYAN + " ice " + Color.RESET + "axe is on the ground.",
            "a " + Color.BOLD_ON + Color.RED + "vulcerium" + Color.RESET + Color.CYAN + " ice " + Color.RESET + "axe",
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    HELGIS_POTION(111, Arrays.asList("Helgi's potion", "potion", "Helgi's", "H", "p"),
            Color.BOLD_ON + Color.RED + "Helgi's" + Color.RESET + Color.MAGENTA + Color.BOLD_ON + " potion" + Color.RESET,
            "a " + Color.BOLD_ON + Color.RED + "Helgi's" + Color.RESET + Color.MAGENTA + Color.BOLD_ON + " potion" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.RED + "Helgi's" + Color.RESET + Color.MAGENTA + Color.BOLD_ON + " potion" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    CELESTIAL_DIAL(112, Arrays.asList("celestial dial", "dial", "c", "d", "celestial"),
            Color.BOLD_ON + Color.CYAN + "celestial" + Color.RESET + Color.WHITE + Color.BOLD_ON + " dial" + Color.RESET,
            "a " + Color.BOLD_ON + Color.CYAN + "celestial" + Color.RESET + Color.WHITE + Color.BOLD_ON + " dial" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.CYAN + "celestial" + Color.RESET + Color.WHITE + Color.BOLD_ON + " dial" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    THORS_LANTERN(113, Arrays.asList("Thor's lantern", "lantern", "Thor's", "T", "l"),
            Color.BOLD_ON + Color.RED + "Thor's" + Color.RESET + Color.YELLOW + " lantern" + Color.RESET,
            "a " + Color.BOLD_ON + Color.RED + "Thor's" + Color.RESET + Color.YELLOW + " lantern" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.RED + "Thor's" + Color.RESET + Color.YELLOW + " lantern" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    ORNATE_CROWN(114, Arrays.asList("ornate crown", "crown", "o", "c", "ornate"),
            Color.BOLD_ON + Color.MAGENTA + "ornate" + Color.RESET + Color.YELLOW + " crown" + Color.RESET,
            "a " + Color.BOLD_ON + Color.MAGENTA + "ornate" + Color.RESET + Color.YELLOW + " crown" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.MAGENTA + "ornate" + Color.RESET + Color.YELLOW + " crown" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    PYAMITE_COMPASS(115, Arrays.asList("pyamite compass", "compass", "p", "c", "pyamite"),
            Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " compass" + Color.RESET,
            "a " + Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " compass" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " compass" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    PYAMITE_ICEAXE(116, Arrays.asList("pyamite ice axe", "ice axe", "axe", "p", "ice", "a"),
            Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " ice " + Color.RESET + "axe",
            "a " + Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " ice " + Color.RESET + "axe is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " ice " + Color.RESET + "axe",
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    IRON_LOCKPICKING_SET(117, Arrays.asList("iron lockpicking set", "lockpicking set", "set", "lockpicking", "i", "l", "s"),
            Color.WHITE + "iron" + Color.RESET + Color.CYAN + " lockpicking " + Color.RESET + "set",
            "an " + Color.WHITE + "iron" + Color.RESET + Color.CYAN + " lockpicking " + Color.RESET + "set is on the ground.",
            "an " + Color.WHITE + "iron" + Color.RESET + Color.CYAN + " lockpicking " + Color.RESET + "set",
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    PYAMITE_LOCKPICKING_SET(118, Arrays.asList("pyamite lockpicking set", "lockpicking set", "set", "lockpicking", "p", "l", "s"),
            Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " lockpicking " + Color.RESET + "set",
            "a " + Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " lockpicking " + Color.RESET + "set is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "pyamite" + Color.RESET + Color.CYAN + " lockpicking " + Color.RESET + "set",
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    SPOOL_OF_CLIMBING_ROPE(119, Arrays.asList("spool of climbing rope", "spool", "climbing rope", "rope", "s", "r"),
            Color.WHITE + "spool of" + Color.RESET + Color.CYAN + " climbing " + Color.RESET + "rope",
            "a " + Color.WHITE + "spool of" + Color.RESET + Color.CYAN + " climbing " + Color.RESET + "rope is on the ground.",
            "a " + Color.WHITE + "spool of" + Color.RESET + Color.CYAN + " climbing " + Color.RESET + "rope",
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    BLACK_CLOAK(120, Arrays.asList("black cloak", "black", "cloak", "b", "c"),
            Color.BOLD_ON + Color.BLACK + "black" + Color.RESET + Color.CYAN + " cloak" + Color.RESET,
            "a " + Color.BOLD_ON + Color.BLACK + "black" + Color.RESET + Color.CYAN + " cloak " + Color.RESET + "is on the ground.",
            "a " + Color.BOLD_ON + Color.BLACK + "black" + Color.RESET + Color.CYAN + " cloak " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    SMELTING_CRUCIBLE(121, Arrays.asList("smelting crucible", "crucible", "smelting", "s", "c"),
            Color.WHITE + "smelting" + Color.RESET + Color.CYAN + " crucible " + Color.RESET,
            "a " + Color.WHITE + "smelting" + Color.RESET + Color.CYAN + " crucible " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "smelting" + Color.RESET + Color.CYAN + " crucible " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    LEATHER_SHOES(122, Arrays.asList("leather shoes", "leather", "shoes", "l", "s"),
            Color.WHITE + "leather" + Color.RESET + Color.CYAN + " shoes" + Color.RESET,
            "some " + Color.WHITE + "leather" + Color.RESET + Color.CYAN + " shoes " + Color.RESET + "are on the ground.",
            "some " + Color.WHITE + "leather" + Color.RESET + Color.CYAN + " shoes " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    GENTLEMANS_TOP_HAT(123, Arrays.asList("gentleman's top hat", "top hat", "hat", "g", "t", "h"),
            Color.WHITE + "gentleman's" + Color.RESET + Color.CYAN + " top hat" + Color.RESET,
            "a " + Color.WHITE + "gentleman's" + Color.RESET + Color.CYAN + " top hat " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "gentleman's" + Color.RESET + Color.CYAN + " top hat " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    LEATHER_GLOVES(124, Arrays.asList("leather gloves", "leather", "gloves", "l", "g"),
            Color.WHITE + "leather" + Color.RESET + Color.CYAN + " gloves " + Color.RESET,
            "a pair of " + Color.WHITE + "leather" + Color.RESET + Color.CYAN + " gloves " + Color.RESET + "is on the ground.",
            "a pair of " + Color.WHITE + "leather" + Color.RESET + Color.CYAN + " gloves " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    WOOL_SCARF(125, Arrays.asList("wool scarf", "wool", "scarf", "w", "s"),
            Color.WHITE + "wool" + Color.RESET + Color.CYAN + " scarf " + Color.RESET,
            "a " + Color.WHITE + "wool" + Color.RESET + Color.CYAN + " scarf " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "wool" + Color.RESET + Color.CYAN + " scarf " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    LEATHER_BELT(126, Arrays.asList("leather belt", "leather", "belt", "l", "b"),
            Color.WHITE + "leather" + Color.RESET + Color.CYAN + " belt " + Color.RESET,
            "a " + Color.WHITE + "leather" + Color.RESET + Color.CYAN + " belt " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "leather" + Color.RESET + Color.CYAN + " belt " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    SILK_SASH(127, Arrays.asList("silk sash", "silk", "sash", "s"),
            Color.WHITE + "silk" + Color.RESET + Color.CYAN + " sash " + Color.RESET,
            "a " + Color.WHITE + "silk" + Color.RESET + Color.CYAN + " sash " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "silk" + Color.RESET + Color.CYAN + " sash " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    LEATHER_SCABBARD(128, Arrays.asList("leather scabbard", "leather", "scabbard", "s", "l"),
            Color.WHITE + "leather" + Color.RESET + Color.CYAN + " scabbard " + Color.RESET,
            "a " + Color.WHITE + "leather" + Color.RESET + Color.CYAN + " scabbard " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "leather" + Color.RESET + Color.CYAN + " scabbard " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    BYSENSKIN_SCABBARD(129, Arrays.asList("bysen skin scabbard", "bysen skin", "scabbard", "s", "b"),
            Color.WHITE + "bysen skin" + Color.RESET + Color.CYAN + " scabbard " + Color.RESET,
            "a " + Color.WHITE + "bysen skin" + Color.RESET + Color.CYAN + " scabbard " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "bysen skin" + Color.RESET + Color.CYAN + " scabbard " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    IRON_SPECTACLES(130, Arrays.asList("iron spectacles", "iron", "spectacles", "i", "s"),
            Color.WHITE + "iron" + Color.RESET + Color.CYAN + " spectacles " + Color.RESET,
            "a pair of " + Color.WHITE + "iron" + Color.RESET + Color.CYAN + " spectacles " + Color.RESET + "are on the ground.",
            "a pair of " + Color.WHITE + "iron" + Color.RESET + Color.CYAN + " spectacles " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    GOLDEN_SPECTACLES(131, Arrays.asList("golden spectacles", "golden", "spectacles", "s", "g"),
            Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " spectacles " + Color.RESET,
            "a pair of " + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " spectacles " + Color.RESET + "are on the ground.",
            "a pair of " + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " spectacles " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    NOBLEMANS_SHOULDER_CLASP(132, Arrays.asList("nobleman's shoulder clasp", "nobleman's", "shoulder clasp", "clasp", "n", "s", "c"),
            Color.MAGENTA + "nobleman's" + Color.RESET + Color.CYAN + " shoulder clasp " + Color.RESET,
            "a " + Color.MAGENTA + "nobleman's" + Color.RESET + Color.CYAN + " shoulder clasp " + Color.RESET + "is on the ground.",
            "a " + Color.MAGENTA + "nobleman's" + Color.RESET + Color.CYAN + " shoulder clasp " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    WOODSMANS_TUNIC(133, Arrays.asList("woodsman's tunic", "woodsman's", "tunic", "w", "t"),
            Color.WHITE + "woodsman's" + Color.RESET + Color.CYAN + " tunic " + Color.RESET,
            "a " + Color.WHITE + "woodsman's" + Color.RESET + Color.CYAN + " tunic " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "woodsman's" + Color.RESET + Color.CYAN + " tunic " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    PLAIN_WHITE_ROBE(134, Arrays.asList("plain white robe", "white robe", "robe", "w", "r"),
            Color.WHITE + "plain white" + Color.RESET + Color.CYAN + " robe " + Color.RESET,
            "a " + Color.WHITE + "plain white" + Color.RESET + Color.CYAN + " robe " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "plain white" + Color.RESET + Color.CYAN + " robe " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    FINE_POWDERED_WIG(135, Arrays.asList("fine powdered wig", "powdered wig", "wig", "p", "w"),
            Color.WHITE + "fine powdered" + Color.RESET + Color.CYAN + " wig " + Color.RESET,
            "a " + Color.WHITE + "fine powdered" + Color.RESET + Color.CYAN + " wig " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "fine powdered" + Color.RESET + Color.CYAN + " wig " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    HABROK_FEATHER_HAT(136, Arrays.asList("habrok feather hat", "feather hat", "hat", "f", "h"),
            Color.WHITE + "habrok feather" + Color.RESET + Color.CYAN + " hat " + Color.RESET,
            "a " + Color.WHITE + "habrok feather" + Color.RESET + Color.CYAN + " hat " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "habrok feather" + Color.RESET + Color.CYAN + " hat " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    POLISHED_IRON_CODPIECE(137, Arrays.asList("polished iron codpiece", "iron codpiece", "codpiece", "i", "c"),
            Color.WHITE + "polished iron" + Color.RESET + Color.CYAN + " codpiece " + Color.RESET,
            "a " + Color.WHITE + "polished iron" + Color.RESET + Color.CYAN + " codpiece " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "polished iron" + Color.RESET + Color.CYAN + " codpiece " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    GOLDEN_CODPIECE(138, Arrays.asList("golden codpiece", "codpiece", "golden", "g", "c"),
            Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " codpiece " + Color.RESET,
            "a shimmering " + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " codpiece " + Color.RESET + "is on the ground.",
            "a shimmering " + Color.YELLOW + "golden" + Color.RESET + Color.CYAN + " codpiece " + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VIAGRA_SWORD(139, Arrays.asList("sword", "viagra sword", "viagra sword"),
            Color.GREEN + "viagra" + Color.RESET + Color.RED + " sword" + Color.RESET,
            "a " + Color.GREEN + "viagra" + Color.RESET + Color.RED + " sword" + Color.RESET + " is on the ground.",
            "a " + Color.GREEN + "viagra" + Color.RESET + Color.RED + " sword" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            100000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    RADSUIT_CHESTPLATE(140, Arrays.asList("chestplate", "a radsuit chestplate", "radsuit chestplate", "radsuit"),
            Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " chestplate" + Color.RESET,
            "a " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " chestplate" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " chestplate" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            100000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    RADSUIT_HELMET(141, Arrays.asList("helmet", "a radsuit helmet", "radsuit helmet", "radsuit"),
            Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " helmet" + Color.RESET,
            "a " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " helmet" + Color.RESET + " is on the ground.",
            "a " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " helmet" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            100000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    RADSUIT_BRACERS(142, Arrays.asList("bracers", "radsuit bracers", "radsuit"),
            Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " bracers" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " bracers" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " bracers" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            100000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    RADSUIT_LEGGINGS(143, Arrays.asList("leggings", "radsuit leggings", "radsuit"),
            Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " leggings" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " leggings" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " leggings" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            100000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    RADSUIT_BOOTS(144, Arrays.asList("boots", "radsuit boots", "radsuit"),
            Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " boots" + Color.RESET,
            "a pair of " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " boots" + Color.RESET + " are on the ground.",
            "a pair of " + Color.BOLD_ON + Color.GREEN + "radsuit" + Color.RESET + Color.MAGENTA + " boots" + Color.RESET,
            false,
            0,
            60,
            true,
            Rarity.LEGENDARY,
            100000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    CRYSTALLINE_TABLET(145, Arrays.asList("crystalline tablet", "crystalline", "tablet", "c", "t"),
            Color.CYAN + "crystalline" + Color.RESET + Color.YELLOW + " tablet" + Color.RESET,
            "a " + Color.CYAN + "crystalline" + Color.RESET + Color.YELLOW + " tablet " + Color.RESET + "is on the ground.",
            "a " + Color.CYAN + "golden" + Color.RESET + Color.YELLOW + " tablet" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    STRAND_OF_ALYXITE(146, Arrays.asList("strand of alyxite", "strand", "alyxite", "s", "a"),
            Color.WHITE + "strand of" + Color.RESET + Color.BOLD_ON + Color.RED + " alyxite" + Color.RESET,
            "a " + Color.WHITE + "strand of" + Color.RESET + Color.BOLD_ON + Color.RED + " alyxite " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "strand of" + Color.RESET + Color.BOLD_ON + Color.RED + " alyxite" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    GARMR_HIDE(147, Arrays.asList("garmr hide", "garmr", "hide", "g", "h"),
            Color.WHITE + "garmr" + Color.RESET + Color.BOLD_ON + Color.RED + " hide" + Color.RESET,
            "a " + Color.WHITE + "garmr" + Color.RESET + Color.BOLD_ON + Color.RED + " hide " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + "garmr" + Color.RESET + Color.BOLD_ON + Color.RED + " hide" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    STROMAN_GRAVER(148, Arrays.asList("stroman graver", "stroman", "graver", "s", "g"),
            Color.RED + Color.BOLD_ON + "stroman" + Color.RESET + Color.BOLD_ON + Color.GREEN + " graver" + Color.RESET,
            "a " + Color.RED + Color.BOLD_ON + "stroman" + Color.RESET + Color.BOLD_ON + Color.GREEN + " graver " + Color.RESET + "is on the ground.",
            "a " + Color.RED + Color.BOLD_ON + "stroman" + Color.RESET + Color.BOLD_ON + Color.GREEN + " graver" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    VOLCANIC_GYROSCOPE(149, Arrays.asList("volcanic gyroscope", "volcanic", "gyroscope", "v", "g"),
            Color.BLACK + Color.BOLD_ON + "volcanic" + Color.RESET + Color.BOLD_ON + Color.CYAN + " gyroscope" + Color.RESET,
            "a " + Color.BLACK + Color.BOLD_ON + "volcanic" + Color.RESET + Color.BOLD_ON + Color.CYAN + " gyroscope " + Color.RESET + "is on the ground.",
            "a " + Color.BLACK + Color.BOLD_ON + "volcanic" + Color.RESET + Color.BOLD_ON + Color.CYAN + " gyroscope" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),

    BASALT_WAND(150, Arrays.asList("basalt wand", "basalt", "wand", "b", "w"),
            Color.BLACK + Color.BOLD_ON + "basalt" + Color.RESET + Color.BOLD_ON + Color.RED + " wand" + Color.RESET,
            "a " + Color.BLACK + Color.BOLD_ON + "basalt" + Color.RESET + Color.BOLD_ON + Color.RED + " wand " + Color.RESET + "is on the ground.",
            "a " + Color.BLACK + Color.BOLD_ON + "basalt" + Color.RESET + Color.BOLD_ON + Color.RED + " wand" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    SPIRAL_MAGNET(151, Arrays.asList("spiral magnet", "spiral", "magnet", "s", "m"),
            Color.GREEN + Color.BOLD_ON + "spiral" + Color.RESET + Color.BOLD_ON + Color.BLACK + " magnet" + Color.RESET,
            "a " + Color.GREEN + Color.BOLD_ON + "spiral" + Color.RESET + Color.BOLD_ON + Color.BLACK + " magnet " + Color.RESET + "is on the ground.",
            "a " + Color.GREEN + Color.BOLD_ON + "spiral" + Color.RESET + Color.BOLD_ON + Color.BLACK + " magnet" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    SANDSTONE_RUNE(152, Arrays.asList("sandstone rune", "sandstone", "rune", "s", "r"),
            Color.YELLOW + Color.BOLD_ON + "sandstone" + Color.RESET + Color.BOLD_ON + Color.BLACK + " rune" + Color.RESET,
            "a " + Color.YELLOW + Color.BOLD_ON + "sandstone" + Color.RESET + Color.BOLD_ON + Color.BLACK + " rune " + Color.RESET + "is on the ground.",
            "a " + Color.YELLOW + Color.BOLD_ON + "sandstone" + Color.RESET + Color.BOLD_ON + Color.BLACK + " rune" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    SERRATED_TALON(153, Arrays.asList("serrated talon", "serrated", "talon", "s", "t"),
            Color.WHITE + Color.BOLD_ON + "serrated" + Color.RESET + Color.BOLD_ON + Color.RED + " talon" + Color.RESET,
            "a " + Color.WHITE + Color.BOLD_ON + "serrated" + Color.RESET + Color.BOLD_ON + Color.RED + " talon " + Color.RESET + "is on the ground.",
            "a " + Color.WHITE + Color.BOLD_ON + "serrated" + Color.RESET + Color.BOLD_ON + Color.RED + " talon" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    GOLDEN_AMULET(154, Arrays.asList("golden amulet", "golden", "amulet", "g", "a"),
            Color.YELLOW + Color.BOLD_ON + "golden" + Color.RESET + Color.BOLD_ON + Color.MAGENTA + " amulet" + Color.RESET,
            "a " + Color.YELLOW + Color.BOLD_ON + "golden" + Color.RESET + Color.BOLD_ON + Color.MAGENTA + " amulet " + Color.RESET + "is on the ground.",
            "a " + Color.YELLOW + Color.BOLD_ON + "golden" + Color.RESET + Color.BOLD_ON + Color.MAGENTA + " amulet" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    RUBY_CROWN(155, Arrays.asList("ruby crown", "ruby", "crown", "r", "c"),
            Color.RED + Color.BOLD_ON + "ruby" + Color.RESET + Color.BOLD_ON + Color.YELLOW + " crown" + Color.RESET,
            "a " + Color.RED + Color.BOLD_ON + "ruby" + Color.RESET + Color.BOLD_ON + Color.YELLOW + " crown " + Color.RESET + "is on the ground.",
            "a " + Color.RED + Color.BOLD_ON + "ruby" + Color.RESET + Color.BOLD_ON + Color.YELLOW + " crown" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    POTION_OF_CLARITY(156, Arrays.asList("potion of clarity", "potion", "clarity", "p", "c"),
            Color.MAGENTA + Color.BOLD_ON + "potion" + Color.RESET + " of" + Color.BOLD_ON + Color.CYAN + " clarity" + Color.RESET,
            "a " + Color.MAGENTA + Color.BOLD_ON + "potion" + Color.RESET + " of" + Color.BOLD_ON + Color.CYAN + " clarity " + Color.RESET + "is on the ground.",
            "a " + Color.MAGENTA + Color.BOLD_ON + "potion" + Color.RESET + " of" + Color.BOLD_ON + Color.CYAN + " clarity" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    LENS_OF_TIME(157, Arrays.asList("lens of time", "lens", "time", "l", "t"),
            Color.CYAN + Color.BOLD_ON + "lens" + Color.RESET + " of" + Color.BOLD_ON + Color.RED + " time" + Color.RESET,
            "a " + Color.CYAN + Color.BOLD_ON + "lens" + Color.RESET + " of" + Color.BOLD_ON + Color.RED + " time " + Color.RESET + "is on the ground.",
            "a " + Color.CYAN + Color.BOLD_ON + "lens" + Color.RESET + " of" + Color.BOLD_ON + Color.RED + " time" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet()),
            
    SAUSAGE_STUFFER(158, Arrays.asList("sausage stuffer", "sausage", "stuffer", "s"),
            Color.RED + Color.BOLD_ON + "sausage" + Color.RESET + Color.BOLD_ON + Color.RED + " stuffer" + Color.RESET,
            "a " + Color.RED + Color.BOLD_ON + "sausage" + Color.RESET + Color.BOLD_ON + Color.RED + " stuffer " + Color.RESET + "is on the ground.",
            "a " + Color.RED + Color.BOLD_ON + "sausage" + Color.RESET + Color.BOLD_ON + Color.RED + " stuffer" + Color.RESET,
            false,
            0,
            60,
            false,
            Rarity.LEGENDARY,
            8000000, Sets.<TimeTracker.TimeOfDay>newHashSet());
            
    
            
    private final Integer itemTypeCode;
    private final List<String> itemTriggers;
    private final String restingName;
    private final String itemName;
    private final String itemDescription;
    private final boolean isDisposable;
    private final int maxUses;
    private final int itemHalfLifeTicks;
    private final boolean isEquipment;
    private final Rarity rarity;
    private final int valueInGold;
    private final Set<TimeTracker.TimeOfDay> validTimeOfDays;

    ItemType(Integer itemTypeCode, List<String> itemTriggers, String itemName, String restingName, String itemDescription, boolean isDisposable, int maxUses, int itemHalfLifeTicks, boolean isEquipment, Rarity rarity, int valueInGold, Set<TimeTracker.TimeOfDay> validTimeOfDays) {
        this.itemTypeCode = itemTypeCode;
        this.itemTriggers = itemTriggers;
        this.itemName = itemName;
        this.restingName = restingName;
        this.itemDescription = itemDescription;
        this.maxUses = maxUses;
        this.isDisposable = maxUses > 0 || isDisposable;
        this.itemHalfLifeTicks = itemHalfLifeTicks;
        this.isEquipment = isEquipment;
        this.rarity = rarity;
        this.valueInGold = valueInGold;
        this.validTimeOfDays = validTimeOfDays;
    }

    public Item create() {
        Item newItem = new Item(getItemName(), getItemDescription(), getItemTriggers(), getRestingName(), UUID.randomUUID().toString(), getItemTypeCode(), 0, false, itemHalfLifeTicks, getRarity(), getValueInGold());
        if (isEquipment) {
            return EquipmentBuilder.Build(newItem);
        }
        return newItem;
    }

    public Rarity getRarity() {
        return rarity;
    }

    public String getRestingName() {
        return restingName;
    }

    public Integer getItemTypeCode() {
        return itemTypeCode;
    }

    public List<String> getItemTriggers() {
        return itemTriggers;
    }

    public String getItemName() {
        return itemName;
    }

    public String getItemDescription() {
        return itemDescription;
    }

    public boolean isDisposable() {
        return isDisposable;
    }

    public int getMaxUses() {
        return maxUses;
    }

    public int getValueInGold() {
        return valueInGold;
    }

    public Set<TimeTracker.TimeOfDay> getValidTimeOfDays() {
        return validTimeOfDays;
    }

    public static ItemType itemTypeFromCode(Integer code) {
        ItemType[] values = values();
        for (ItemType type : values) {
            if (type.getItemTypeCode().equals(code)) {
                return type;
            }
        }
        return ItemType.UNKNOWN;
    }
}
